@@ -9,22 +9,22 @@ class MakeRssComments < MakeRssFull
 	def title
 		'(comments only)'
 	end
-	
+
 	def item( seq, body, rdfsec )
 		return if rdfsec.section.respond_to?( :body_to_html )
 		super
 	end
-	
+
 	def file
 		f = @conf['makerss.no_comments.file'] || 'comments.rdf'
 		f = 'comments.rdf' if f.length == 0
-		f
+		f =~ %r|^/| ? f : "#{document_root}/#{f}"
 	end
-	
+
 	def write( encoder )
 		super( encoder )
 	end
-	
+
 	def url
 		u = @conf['makerss.no_comments.url'] || "#{@conf.base_url}comments.rdf"
 		u = "#{@conf.base_url}comments.rdf" if u.length == 0
@@ -32,4 +32,4 @@ class MakeRssComments < MakeRssFull
 	end
 end
 
-@makerss_rsses << MakeRssComments::new( @conf )
+@makerss_rsses << MakeRssComments::new( @conf, @cgi )
